SubgraphNode

Struct SubgraphNode 

pub struct SubgraphNode<S: StateSchema, SubS: StateSchema> { /* private fields */ }
Subgraph Node - A node that executes a nested compiled graph

This allows composition of graphs by embedding one graph inside another. The subgraph receives mapped input state and returns mapped output state.

Implementations

Source

impl<S: StateSchema, SubS: StateSchema> SubgraphNode<S, SubS>

pub fn new( name: impl Into<String>, subgraph: CompiledGraph<SubS>, input_mapper: impl Fn(&S) -> SubS + Send + Sync + 'static, output_mapper: impl Fn(&SubS, &mut S) + Send + Sync + 'static, ) -> Self

Source

impl<S: StateSchema + Clone> SubgraphNode<S, S>

pub fn same_state(name: impl Into<String>, subgraph: CompiledGraph<S>) -> Self