Checkpointer

Trait Checkpointer 

pub trait Checkpointer<S: StateSchema>: Send + Sync {
    // Required methods
    fn save<'life0, 'life1, 'async_trait>(
        &'life0 self,
        state: &'life1 S,
        recursion_count: usize,
    ) -> Pin<Box<dyn Future<Output = GraphResult<String>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn load<'life0, 'life1, 'async_trait>(
        &'life0 self,
        checkpoint_id: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = GraphResult<S>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn list<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = GraphResult<Vec<String>>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn delete<'life0, 'life1, 'async_trait>(
        &'life0 self,
        checkpoint_id: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = GraphResult<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn last<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = GraphResult<Option<(S, usize)>>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Checkpointer trait for state persistence

Required Methods

fn save<'life0, 'life1, 'async_trait>( &'life0 self, state: &'life1 S, recursion_count: usize, ) -> Pin<Box<dyn Future<Output = GraphResult<String>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Insert a new checkpoint, recording how much of the recursion budget had been consumed by the run at that point (M6).

fn load<'life0, 'life1, 'async_trait>( &'life0 self, checkpoint_id: &'life1 str, ) -> Pin<Box<dyn Future<Output = GraphResult<S>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn list<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = GraphResult<Vec<String>>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

List checkpoint ids, ordered from oldest to most recent (H5).

fn delete<'life0, 'life1, 'async_trait>( &'life0 self, checkpoint_id: &'life1 str, ) -> Pin<Box<dyn Future<Output = GraphResult<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn last<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = GraphResult<Option<(S, usize)>>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

State and recursion budget of the most recently saved checkpoint.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors