Public types for graph execution results and streaming events
Structs
- Dynamic
Injection - Result of dynamic planning: nodes and edges to inject into a running graph.
- Dynamic
Task - A task submitted externally for dynamic planning mid-execution.
- Graph
Execution - GraphExecution - State for interrupted execution that can be resumed
- Graph
Invocation - GraphInvocation - Result of graph execution
- Parallel
Branch - ParallelBranch - Result of a parallel execution branch
- Parallel
Invocation - ParallelInvocation - Result of graph execution with parallel branches
Enums
- Execution
Step - ExecutionStep - Single step in execution history
- Stream
Event - StreamEvent - Event for streaming execution
Traits
- Dynamic
Planner - Planner trait for converting external tasks into graph nodes/edges at runtime.