State management for LangGraph
This module provides the state abstraction for graph execution. States are data structures that flow through nodes in the graph.
Structs
- Agent
State - Common state with messages (agent-style)
- Append
Messages Reducer - AgentState Messages Reducer - Appends messages instead of replacing
- Append
Reducer - Append reducer for vector fields (like add_messages pattern)
- Append
Steps Reducer - AgentState Steps Reducer - Appends steps instead of replacing
- Message
Entry - Message entry for agent state
- Replace
Reducer - Default reducer that replaces state entirely
- State
Update - State update representation
- Step
Entry - Step entry for intermediate execution steps
Enums
- Message
Role - Message role types
Traits
- Reducer
- Reducer trait for merging state updates
- State
Schema - State Schema trait