AppendReducer

Struct AppendReducer 

pub struct AppendReducer<S: StateSchema, T: Clone + Send + Sync> {
    pub field_accessor: fn(&S) -> &[T],
    pub field_mutator: fn(&mut S, Vec<T>),
}
Append reducer for vector fields (like add_messages pattern)

This reducer appends new items to vector fields in the state. Useful for message history, steps history, etc.

Fields

field_accessor: fn(&S) -> &[T]

Function that reads the vector field from a state.

field_mutator: fn(&mut S, Vec<T>)

Function that writes the merged vector back into a state.